@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.4 (main, Apr  2 2022, 09:04:19) [GCC 11.2.0]
+# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -1114,13 +1114,10 @@ class IdentifierType(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='IdentifierType')
-        if self._hasContent():
-            outfile.write('>')
-            outfile.write(self.convert_unicode(self.valueOf_))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='IdentifierType', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
+        outfile.write('>')
+        self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_, pretty_print=pretty_print)
+        outfile.write(self.convert_unicode(self.valueOf_))
+        outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
     def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='IdentifierType'):
         if self.schemeID is not None and 'schemeID' not in already_processed:
             already_processed.add('schemeID')
@@ -1259,13 +1256,10 @@ class BillOfResourcesIDType(IdentifierType):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='BillOfResourcesIDType')
-        if self._hasContent():
-            outfile.write('>')
-            outfile.write(self.convert_unicode(self.valueOf_))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='BillOfResourcesIDType', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
+        outfile.write('>')
+        self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_, pretty_print=pretty_print)
+        outfile.write(self.convert_unicode(self.valueOf_))
+        outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
     def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='BillOfResourcesIDType'):
         super(BillOfResourcesIDType, self)._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='BillOfResourcesIDType')
     def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='BillOfResourcesIDType', fromsubclass_=False, pretty_print=True):
@@ -1346,13 +1340,10 @@ class BillOfMaterialIDType(IdentifierType):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='BillOfMaterialIDType')
-        if self._hasContent():
-            outfile.write('>')
-            outfile.write(self.convert_unicode(self.valueOf_))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='BillOfMaterialIDType', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
+        outfile.write('>')
+        self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_, pretty_print=pretty_print)
+        outfile.write(self.convert_unicode(self.valueOf_))
+        outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
     def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='BillOfMaterialIDType'):
         super(BillOfMaterialIDType, self)._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='BillOfMaterialIDType')
     def _exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='BillOfMaterialIDType', fromsubclass_=False, pretty_print=True):
