@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.10.4 (main, Apr  2 2022, 09:04:19) [GCC 11.2.0]
+# Python 3.10.6 (main, Nov 14 2022, 16:10:14) [GCC 11.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -1095,13 +1095,10 @@ class SpecialDate(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='SpecialDate')
-        if self._hasContent():
-            outfile.write('>')
-            outfile.write(self.convert_unicode(self.valueOf_))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='SpecialDate', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
+        outfile.write('>')
+        self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_, pretty_print=pretty_print)
+        outfile.write(self.convert_unicode(self.valueOf_))
+        outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
     def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='SpecialDate'):
         if self.SpecialProperty is not None and 'SpecialProperty' not in already_processed:
             already_processed.add('SpecialProperty')
@@ -1218,13 +1215,10 @@ class ExtremeDate(GeneratedsSuper):
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
         self._exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='ExtremeDate')
-        if self._hasContent():
-            outfile.write('>')
-            outfile.write(self.convert_unicode(self.valueOf_))
-            self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='ExtremeDate', pretty_print=pretty_print)
-            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
-        else:
-            outfile.write('/>%s' % (eol_, ))
+        outfile.write('>')
+        self._exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_, pretty_print=pretty_print)
+        outfile.write(self.convert_unicode(self.valueOf_))
+        outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
     def _exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='ExtremeDate'):
         if self.ExtremeProperty is not None and 'ExtremeProperty' not in already_processed:
             already_processed.add('ExtremeProperty')
